package nl.kallestruik.darena.util

import nl.kallestruik.darena.exceptions.MaterialNotFoundException
import org.bukkit.Material
import org.bukkit.configuration.file.YamlConfiguration
import org.bukkit.configuration.ConfigurationSection
import java.io.*

object ConfigHelper {

    fun getOrCreateConfig(file: File, template: String): YamlConfiguration {
        if (!file.parentFile.exists())
            file.parentFile.mkdirs()
        if (!file.exists())
            createConfig(file, template)

        val config = YamlConfiguration()
        config.load(file)
        return config
    }

    private fun createConfig(file: File, template: String) {
        try {
            ConfigHelper.javaClass.getResourceAsStream("/$template").use { stream ->
                FileOutputStream(file).use { resStreamOut ->
                    if (stream == null) {
                        throw IOException("Cannot get resource \"$template\" from Jar file.")
                    }
                    var readBytes: Int
                    val buffer = ByteArray(4096)
                    while (stream.read(buffer).also { readBytes = it } > 0) {
                        resStreamOut.write(buffer, 0, readBytes)
                    }
                }
            }
        } catch (e: IOException) {
            e.printStackTrace()
        }
    }

    @Throws(MaterialNotFoundException::class)
    fun matchMaterial(material: String): Material {
        return Material.matchMaterial(material) ?: throw MaterialNotFoundException("There is not material with the name '$material'")
    }

    fun parseIntList(string: String): List<Int> {
        val list = mutableListOf<Int>()
        for (key in string.split(" ")) {
            list.add(key.toInt())
        }
        return list
    }

    fun parseStringIntListMap(section: ConfigurationSection): Map<String, List<Int>> {
        val map = mutableMapOf<String, List<Int>>()
        for (key in section.getKeys(true)) {
            map[key] = parseIntList(section.getString(key)!!)
        }

        return map
    }
}
